mutation CreateCloudChatFromRepository($repositoryUuid: String!, $provider: SandboxProvider) {
    createCloudChat(repositoryUuid: $repositoryUuid, provider: $provider) {
        __typename
        ... on Chat {
            chatUuid
        }
        ... on UnauthenticatedError {
            message
        }
        ... on NotFoundError {
            resourceType
            resourceId
            message
        }
        ... on CloudSessionError {
            message
        }
    }
}
