# Generated by ariadne-codegen
# Source: exponent/core/graphql/operations

from typing import Literal, Optional, Union

from pydantic import Field

from .base_model import BaseModel


class CreateCloudChatFromRepository(BaseModel):
    create_cloud_chat: Union[
        "CreateCloudChatFromRepositoryCreateCloudChatChat",
        "CreateCloudChatFromRepositoryCreateCloudChatNotFoundError",
        "CreateCloudChatFromRepositoryCreateCloudChatCloudSessionError",
        "CreateCloudChatFromRepositoryCreateCloudChatError",
        "CreateCloudChatFromRepositoryCreateCloudChatInputValidationError",
        "CreateCloudChatFromRepositoryCreateCloudChatPlanError",
        "CreateCloudChatFromRepositoryCreateCloudChatUnauthenticatedError",
    ] = Field(alias="createCloudChat", discriminator="typename__")


class CreateCloudChatFromRepositoryCreateCloudChatChat(BaseModel):
    typename__: Literal["Chat"] = Field(alias="__typename")
    chat_uuid: str = Field(alias="chatUuid")


class CreateCloudChatFromRepositoryCreateCloudChatNotFoundError(BaseModel):
    typename__: Literal["NotFoundError"] = Field(alias="__typename")
    resource_type: str = Field(alias="resourceType")
    resource_id: Optional[str] = Field(alias="resourceId")
    message: str


class CreateCloudChatFromRepositoryCreateCloudChatCloudSessionError(BaseModel):
    typename__: Literal["CloudSessionError"] = Field(alias="__typename")
    message: str


class CreateCloudChatFromRepositoryCreateCloudChatError(BaseModel):
    typename__: Literal["Error"] = Field(alias="__typename")


class CreateCloudChatFromRepositoryCreateCloudChatInputValidationError(BaseModel):
    typename__: Literal["InputValidationError"] = Field(alias="__typename")


class CreateCloudChatFromRepositoryCreateCloudChatPlanError(BaseModel):
    typename__: Literal["PlanError"] = Field(alias="__typename")


class CreateCloudChatFromRepositoryCreateCloudChatUnauthenticatedError(BaseModel):
    typename__: Literal["UnauthenticatedError"] = Field(alias="__typename")
    message: str


CreateCloudChatFromRepository.model_rebuild()
